/*******************************************************************************
* File Name: MyPin.c  
* Version 2.0
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "MyPin.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 MyPin__PORT == 15 && ((MyPin__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: MyPin_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void MyPin_Write(uint8 value) 
{
    uint8 staticBits = (MyPin_DR & (uint8)(~MyPin_MASK));
    MyPin_DR = staticBits | ((uint8)(value << MyPin_SHIFT) & MyPin_MASK);
}


/*******************************************************************************
* Function Name: MyPin_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  MyPin_DM_STRONG     Strong Drive 
*  MyPin_DM_OD_HI      Open Drain, Drives High 
*  MyPin_DM_OD_LO      Open Drain, Drives Low 
*  MyPin_DM_RES_UP     Resistive Pull Up 
*  MyPin_DM_RES_DWN    Resistive Pull Down 
*  MyPin_DM_RES_UPDWN  Resistive Pull Up/Down 
*  MyPin_DM_DIG_HIZ    High Impedance Digital 
*  MyPin_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void MyPin_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(MyPin_0, mode);
}


/*******************************************************************************
* Function Name: MyPin_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro MyPin_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 MyPin_Read(void) 
{
    return (MyPin_PS & MyPin_MASK) >> MyPin_SHIFT;
}


/*******************************************************************************
* Function Name: MyPin_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 MyPin_ReadDataReg(void) 
{
    return (MyPin_DR & MyPin_MASK) >> MyPin_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(MyPin_INTSTAT) 

    /*******************************************************************************
    * Function Name: MyPin_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 MyPin_ClearInterrupt(void) 
    {
        return (MyPin_INTSTAT & MyPin_MASK) >> MyPin_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
